@@ -88,7 +88,13 @@ def logout(request):
     return response
 
 @api_view(["POST"])
+@authentication_classes([])
 def flush_session_view(request):
+    '''
+    this is supposed to be served under a protected router only accessible from inside the network
+    :param request:
+    :return:
+    '''
     email = request.data["email"]
     try:
         user = User.objects.get(email=email)
